==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/General/rdetect/translations/rdetect_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Engadir CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Engadir volume &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Detección de CD de audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Engadir pistas á lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Eliminar pistas da lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Detección de dispositivos extraíbles</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Engadir ficheiros á lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Eliminar ficheiros da lista de reprodución automaticamente</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/rdetect/translations/rdetect_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation>Engadido de detección do volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation>Acerca do engadido de detección do volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation>Engadido Qmmp de detección do volume extraíble</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation>Este engadido fornece a detección de volume extraíble</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Engadir CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Engadir volume &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation>Preferencias do engadido Detección de volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Detección de CD de audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Engadir pistas á lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Eliminar pistas da lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Detección de dispositivos extraíbles</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Engadir ficheiros á lista de reprodución automaticamente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Eliminar ficheiros da lista de reprodución automaticamente</translation>
    </message>
</context>
</TS>
